@@ -17,12 +17,15 @@
 #include <iostream>
 #include <unistd.h>
 #include <stdexcept>
+#include <stdlib.h>
 
-#include "videothumbnailer.h"
+#include "libffmpegthumbnailer/videothumbnailer.h"
+#include "libffmpegthumbnailer/stringoperations.h"
 
 using namespace std;
 
 void printUsage();
+ImageType determineImageType(const std::string& filename);
 
 int main(int argc, char** argv)
 {
@@ -73,12 +76,12 @@ int main(int argc, char** argv)
 		printUsage();
         return 0;
 	}
-		   
+    
 	try
 	{
-		VideoThumbnailer videoThumbailer(inputFile);
-		videoThumbailer.generateThumbnail(outputFile, thumbnailSize, filmStripOverlay, seekPercentage, workaroundIssues);
-	}
+        VideoThumbnailer videoThumbnailer(thumbnailSize, seekPercentage, filmStripOverlay, workaroundIssues);
+		videoThumbnailer.generateThumbnail(inputFile, determineImageType(outputFile), outputFile);
+    }
 	catch (exception& e)
 	{
 		cerr << "Error: " << e.what() << endl;
@@ -94,7 +97,7 @@ int main(int argc, char** argv)
 
 void printUsage()
 {
-	cout << "Usage: ffmpegvideothumbnailer [options]" << endl << endl
+	cout << "Usage: ffmpegthumbnailer [options]" << endl << endl
 		 << "Options:" << endl
 		 << "  -i<s>  : input file" << endl
 		 << "  -o<s>  : output file" << endl
@@ -104,3 +107,17 @@ void printUsage()
          << "  -w     : workaround issues in old versions of ffmpeg" << endl
          << "  -h     : display this help" << endl;
 }
+
+ImageType determineImageType(const std::string& filename)
+{
+    string lowercaseFilename = filename;
+    StringOperations::lowercase(lowercaseFilename);
+    
+    size_t size = lowercaseFilename.size();
+    if ((lowercaseFilename.substr(size - 5, size) == ".jpeg") || (lowercaseFilename.substr(size - 4, size) == ".jpg"))
+    {
+        return Jpeg;
+    }
+    
+    return Png;
+}
